@@ -52,7 +52,7 @@ void edtfunc (float (*func)(short int, short int),
   const int numel = img.numel ();
 
   // Initialize the distance images to be all large values
-  const bool* elem = img.fortran_vec ();
+  const bool* elem = img.data ();
   for (octave_idx_type i = 0; i < numel; i++)
     if(! elem[i])
       {
@@ -421,8 +421,8 @@ static float
 quasi_euclidean (short x, short y)
 {
   static const float sqrt2_1 = sqrt (2) - 1;
-  return abs(x)>abs(y) ? (abs(x) + sqrt2_1 * abs(y)) :
-                         (sqrt2_1 * abs(x) + abs(y)) ;
+  return abs(x)>abs(y) ? (fabs(x) + sqrt2_1 * fabs(y)) :
+                         (sqrt2_1 * fabs(x) + fabs(y)) ;
 }
 
 static FloatMatrix
@@ -493,26 +493,13 @@ Currently, only 2D images are supported.\n\
 
   const int nargin = args.length ();
   if (nargin < 1 || nargin > 2)
-    {
-      print_usage ();
-      return retval;
-    }
+    print_usage ();
 
   // for matlab compatibility, we do not actually check if the values are all
   // 0 and 1, any non-zero value is considered true
   const boolNDArray bw = args (0).bool_array_value ();
-  if (error_state)
-    {
-      error ("bwdist: BW must be a logical matrix");
-      return retval;
-    }
 
   std::string method = (nargin > 1) ? args (1).string_value () : "euclidean";
-  if (error_state)
-    {
-      error ("bwdist: METHOD must be a string");
-      return retval;
-    }
   for (octave_idx_type q = 0; q < octave_idx_type (method.length ()); q++)
     method[q] = tolower (method[q]);
 
@@ -548,7 +535,7 @@ Currently, only 2D images are supported.\n\
           dist = calc_distances (euclidean, bw, xdist, ydist);
           const Array<octave_idx_type> positions = (!bw).find ();
           const int zpos = positions.numel();
-          const octave_idx_type* pos_vec = positions.fortran_vec ();
+          const octave_idx_type* pos_vec = positions.data ();
           float* dist_vec = dist.fortran_vec ();
           for (int i = 0; i < zpos; i++)
             dist_vec[pos_vec[i]] = sqrt (dist_vec[pos_vec[i]]);
