@@ -32,7 +32,7 @@
 #define WANTS_OCTAVE_IMAGE_VALUE 1
 #include "octave-wrappers.h"
 
-using namespace octave::image;
+using namespace octave_image_pkg;
 
 static union_find
 pre_label (NDArray& L, const connectivity& conn)
@@ -42,7 +42,7 @@ pre_label (NDArray& L, const connectivity& conn)
 
   const Array<octave_idx_type> neighbours
     = conn.negative_neighbourhood (L.dims ());
-  const octave_idx_type* nbr = neighbours.fortran_vec ();
+  const octave_idx_type* nbr = neighbours.data ();
   const octave_idx_type nbr_numel = neighbours.numel ();
 
   union_find u_f (numel);
@@ -383,7 +383,7 @@ See, for example, http://en.wikipedia.org/wiki/Union-find\n\
         }
       catch (invalid_connectivity& e)
         {
-          error ("bwlabeln: faild to create MASK (%s)", e.what ());
+          error ("bwlabeln: failed to create MASK (%s)", e.what ());
         }
     }
 
