@@ -29,10 +29,14 @@
 
 #include <octave/ov.h>
 
-namespace octave
+#if defined (HAVE_OCTAVE_DIM_VECTOR_XELEM)
+#  define OCT_DIM_VECTOR_XELEM xelem
+#else
+#  define OCT_DIM_VECTOR_XELEM elem
+#endif
+
+namespace octave_image_pkg
 {
-  namespace image
-  {
     class connectivity
     {
       public:
@@ -89,14 +93,13 @@ namespace octave
     };
 
     connectivity conndef (const octave_value& val);
-  }
 }
 
 // Templated methods
 
 template<class T, class P>
 T
-octave::image::connectivity::create_padded (const T& image, const P& val) const
+octave_image_pkg::connectivity::create_padded (const T& image, const P& val) const
 {
   const octave_idx_type pad_ndims = std::min (mask.ndims (), image.ndims ());
 
@@ -117,7 +120,7 @@ octave::image::connectivity::create_padded (const T& image, const P& val) const
 
 template<class T>
 void
-octave::image::connectivity::unpad (T& image) const
+octave_image_pkg::connectivity::unpad (T& image) const
 {
   const octave_idx_type pad_ndims = std::min (mask.ndims (), image.ndims ());
   const dim_vector padded_size = image.dims ();
@@ -134,7 +137,7 @@ octave::image::connectivity::unpad (T& image) const
 
 template<class P>
 P
-octave::image::connectivity::min_value (void)
+octave_image_pkg::connectivity::min_value (void)
 {
   if (typeid (P) == typeid (bool))
     return false;
@@ -144,17 +147,16 @@ octave::image::connectivity::min_value (void)
 
 template<class T, class P>
 void
-octave::image::connectivity::set_padding (const dim_vector& size,
+octave_image_pkg::connectivity::set_padding (const dim_vector& size,
                                           const dim_vector& padded_size,
                                           T& im, const P& val)
 {
   P* im_v = im.fortran_vec ();
 
   const Array<octave_idx_type> lengths = padding_lengths (size, padded_size);
-  const octave_idx_type* lengths_v = lengths.fortran_vec ();
+  const octave_idx_type* lengths_v = lengths.data ();
 
-  const octave_idx_type* strides_v = size.to_jit ();
-  const octave_idx_type row_stride = strides_v[0];
+  const octave_idx_type row_stride = size.OCT_DIM_VECTOR_XELEM (0);
 
   std::function<void(const octave_idx_type)> fill;
   fill = [&] (const octave_idx_type dim) -> void
@@ -165,7 +167,7 @@ octave::image::connectivity::set_padding (const dim_vector& size,
     if (dim == 0)
       im_v += row_stride;
     else
-      for (octave_idx_type i = 0; i < strides_v[dim]; i++)
+      for (octave_idx_type i = 0; i < size.OCT_DIM_VECTOR_XELEM (dim); i++)
         fill (dim -1);
 
     for (octave_idx_type i = 0; i < lengths_v[dim]; i++, im_v++)
