@@ -26,7 +26,7 @@
 #include "octave-wrappers.h"
 
 #include "connectivity.h"
-using namespace octave::image;
+using namespace octave_image_pkg;
 
 template<class T>
 static boolNDArray
@@ -181,11 +181,11 @@ watershed (const T& im, const connectivity& conn)
   double* label = label_array.fortran_vec ();
 
   const T  padded_im_array = conn.create_padded (im, 0);
-  const P* padded_im = padded_im_array.fortran_vec ();
+  const P* padded_im = padded_im_array.data ();
 
   const Array<octave_idx_type> neighbours_array
     = conn.deleted_neighbourhood (padded_im_array.dims ());
-  const octave_idx_type* neighbours = neighbours_array.fortran_vec ();
+  const octave_idx_type* neighbours = neighbours_array.data ();
   const octave_idx_type n_neighbours = neighbours_array.numel ();
 
   // We need two flags per voxel for this implementation:
@@ -297,7 +297,7 @@ or with a binary matrix representing a connectivity array.  Defaults to\n\
 
   connectivity conn;
   if (nargin > 1)
-    conn = octave::image::conndef (args(1));
+    conn = octave_image_pkg::conndef (args(1));
   else
     {
       try
